@@ -7,19 +7,24 @@
 #' @param fill A character string indicating the color used to fill
 #' the bars (default: "#396D35"). It must be a hexadecimal color code or
 #' a color used by default in R.
+#' @param class_width (default values: NULL) A numeric or an integer specifying
+#' the width of the classes displayed on the histogram. When it is not
+#' specified, the width is equal to the difference between the minimum and
+#' maximum values divided by 80.
 #' @return A ggplot2 object to plot
 #' @import ggplot2
 #' @export
 #' @author P. Savary
 #' @examples
-#' data(data_simul_genind)
-#' mat_w <- mat_gen_dist(data_simul_genind, dist = "DPS")
+#' data(data_ex_genind)
+#' mat_w <- mat_gen_dist(data_ex_genind, dist = "DPS")
 #' gp <- gen_graph_topo(mat_w = mat_w, topo = "gabriel")
 #' hist <- plot_w_hist(gp)
 
 
 plot_w_hist <- function(graph,
-                        fill = "#396D35"){
+                        fill = "#396D35",
+                        class_width = NULL){
 
   # Check whether 'graph' has weighted links
   if(is.null(igraph::E(graph)$weight)){
@@ -34,13 +39,28 @@ plot_w_hist <- function(graph,
   # Give columns' names to 'graph_df'
   names(graph_df) <- c("from", "to", "weight")
 
-  # Get minimum and maximum weights values
-  min_w <- min(graph_df$weight)
-  max_w <- max(graph_df$weight)
+  # Set the class width
 
-  # Calculate the interval to use in order to have 80 classes
-  # between the min and max values
-  b_w <- (max_w - min_w)/80
+  # If not specified, then it depends on the range of values
+  if(is.null(class_width)){
+
+    # Get minimum and maximum weights values
+    min_w <- min(graph_df$weight)
+    max_w <- max(graph_df$weight)
+
+    # Calculate the interval to use in order to have 80 classes
+    # between the min and max values
+    b_w <- (max_w - min_w)/80
+
+    # Else, it is the specified value, provided it is a numeric or an integer
+  } else {
+
+    if(!inherits(class_width, c("numeric", "integer"))){
+      stop("'class_width' must be a numeric or an integer")
+    } else {
+      b_w <- class_width
+    }
+  }
 
   # Plot the histogram
   hist <- ggplot(data = graph_df,
